@@ -4,7 +4,7 @@
  * Description: Provides the interfaces of the libvirt library to handle
  *              errors raised while using the library.
  *
- * Copyright (C) 2006-2015 Red Hat, Inc.
+ * Copyright (C) 2006-2016 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -130,6 +130,8 @@ typedef enum {
     VIR_FROM_LOGGING = 63,      /* Error from log manager */
     VIR_FROM_XENXL = 64,        /* Error from Xen xl config code */
 
+    VIR_FROM_PERF = 65,         /* Error from perf */
+
 # ifdef VIR_ENUM_SENTINELS
     VIR_ERR_DOMAIN_LAST
 # endif
@@ -310,6 +312,11 @@ typedef enum {
                                            CPU*/
     VIR_ERR_XML_INVALID_SCHEMA = 92,    /* XML document doesn't validate against schema */
     VIR_ERR_MIGRATE_FINISH_OK = 93,     /* Finish API succeeded but it is expected to return NULL */
+    VIR_ERR_AUTH_UNAVAILABLE = 94,	/* authentication unavailable */
+    VIR_ERR_NO_SERVER = 95,             /* Server was not found */
+    VIR_ERR_NO_CLIENT = 96,             /* Client was not found */
+    VIR_ERR_AGENT_UNSYNCED = 97,        /* guest agent replies with wrong id
+                                           to guest-sync command */
 } virErrorNumber;
 
 /**
